==> nextcloud-20.0.14.tgz: nextcloud/apps/settings/l10n/mn.js <==
OC.L10N.register(
    "settings",
    {
    "Saved" : "Хадгалагдсан",
    "Sending…" : "Илгээх...",
    "Private" : "Далд",
    "Verify" : "Шалнгах",
    "Unable to change password" : "Нууц үг солих боломжгүй",
    "Very weak password" : "маш муу нууц үг",
    "Weak password" : "муу нууц үг",
    "So-so password" : "ердийн нууц үг",
    "Good password" : "зөв нууц үг ",
    "Strong password" : "баттай нууц үг",
    "Groups" : "Бүлгүүд",
    "{actor} changed your password" : "{actor} таны нууц үгийг солив",
    "You changed your password" : "Та өөрийн нууц үг солив",
    "Your password was reset by an administrator" : "Зохицуулагч таны нууц үгийг солив",
    "{actor} changed your email address" : "{actor} таны цахим шуудангийн хаягийг солив",
    "You changed your email address" : "Та өөрийн цахим шуудангийн хаягийг солив",
    "Your email address was changed by an administrator" : "Зохицуулагч таны цахим шуудангийн хаягийг солив",
    "Security" : "Хамгаалалт",
    "Wrong password" : "Нууц үг буруу байна",
    "Authentication error" : "Нотолгооны алдаа",
    "Invalid SMTP password." : "SMTP -н нууц үг буруу байна ",
    "Email setting test" : "Цахим шуудангийн тохиргоог шалгах",
    "If you received this email, the email configuration seems to be correct." : "Хэрэв та энэ цахим захидалыг хүлээн авсан бол цахим шуудангийн тохиргоо нь зөв байна.",
    "Email could not be sent. Check your mail server log" : "Цахим захидлыг илгээж чадсангүй. Цахим шуудангийн серверийн лог шалгана уу.",
    "Settings saved" : "Тохиргоо хадгалагдлаа",
    "Unable to change full name" : "Бүтэн нэрийг солих боломжгүй",
    "Unable to change email address" : "Цахим шуудангийн хаягийг солих боломжгүй",
    "If you did not request this, please contact an administrator." : "Хэрэв та энэ хүсэлтийг илгээгээгүй бол зохицуулагч руу хандана уу.",
    "Set your password" : "Нууц үгээ тохируулна уу",
    "Apps" : "Аппликэйшинууд",
    "Settings" : "Тохиргоо",
    "Personal" : "Хувийн",
    "Sharing" : "Түгээх",
    "Personal info" : "Хувийн мэдээлэл",
    "Create" : "Үүсгэх",
    "Delete" : "Устгах",
    "None" : "юу ч үгүй",
    "Save changes" : "Өөрчлөлтийг хадгалах",
    "All" : "бүх",
    "No results" : "Үр дүн байхгүй",
    "Update to {version}" : "{version} хувилбар руу шинэчлэх",
    "Remove" : "Устгах",
    "Visit website" : "Цахим хуудсаар зочлох",
    "User documentation" : "Хэрэглэгчийн баримт бичиг",
    "Admin documentation" : "Админы баримт бичиг",
    "Featured" : "Алдартай",
    "Rename" : "Нэрлэнэ үү",
    "Device" : "Төхөөрөмж",
    "Last activity" : "Хамгийн сүүлийн үйлдэл",
    "App name" : "Аппликэйшны нэр",
    "Username" : "Хэрэглэгчийн нэр",
    "Password" : "Нууц үг",
    "Done" : "Дууссан",
    "Copied!" : "Хуулсан!",
    "Copy" : "Хуулах",
    "Language" : "Хэл",
    "Add" : "нэмэх",
    "Cancel" : "Цуцлах",
    "Display name" : "Харагдах нэр",
    "Email" : "Цахим шуудан",
    "Quota" : " хувь хэмжээ",
    "Last login" : "Сүүлд нэвтэрсэн огноо",
    "Unnamed device" : "нэргүй төхөөрөммж",
    "Your apps" : "Таны аппликэйшнүүд",
    "Disabled apps" : "Идэвхижээгүй аппликэйшнүүд",
    "App bundles" : "Аппликэйшны багц",
    "Details" : "Дэлгэрэнгүй",
    "Add group" : "Бүлэг нэмэх",
    "Admins" : "Админууд",
    "Send email to new user" : "Шинэ хэрэглэгч рүү цахим шуудан илгээх",
    "Address" : "Хаяг",
    "Full name" : "Бүтэн нэр",
    "Phone number" : "Утасны дугаар",
    "Twitter" : "Твиттер",
    "Website" : "Цахим хуудас",
    "Never" : "хэзээч",
    "Administrator documentation" : "Админы баримт бичиг",
    "Forum" : "Хэлэлцүүлэг",
    "Login" : "Нэвтрэх",
    "Open documentation" : "бичиг баримт нээх",
    "Server address" : "хүлээн авагчийн хаяг",
    "Port" : "порт",
    "Credentials" : "Итгэмжлэл",
    "SMTP Password" : "Энгийн мэйл дамжуулах протокол-ийн нууц үг",
    "Save" : "Хадгалах",
    "Version" : "Хувилбар",
    "Always ask for a password" : "Үргэлж нууц үг асуух",
    "Enforce password protection" : "Нууц үгийн хамгаалалтыг хэрэгжүүлэх",
    "Profile picture" : "Профайл зураг",
    "Upload new" : "Шинийг байршуулах",
    "Select from Files" : "Файлуудаас сонгох",
    "Remove image" : "Зургийг хасах",
    "Choose as profile picture" : "Профайл зургаа сонгоно уу",
    "Your phone number" : "Таны утасны дугаар",
    "Your postal address" : "Таны шуудангийн хаяг",
    "Current password" : "Одоогийн нууц үг",
    "New password" : "Шинэ нууц үг",
    "Change password" : "Нууц үг солих",
    "Public" : "Нийтийн",
    "Close" : "Хаах",
    "All languages" : "Бүх хэлүүд",
    "Everyone" : "Бүх хэрэглэгчид",
    "mail" : "и-мэйл",
    "Expire after " : " Дуусах хугацаа",
    "days" : "өдрийн дараа"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.3.tgz: nextcloud/apps/settings/l10n/mn.js <==
OC.L10N.register(
    "settings",
    {
    "Saved" : "Хадгалагдсан",
    "Sending…" : "Илгээх...",
    "Private" : "Далд",
    "Verify" : "Шалнгах",
    "Unable to change password" : "Нууц үг солих боломжгүй",
    "Very weak password" : "маш муу нууц үг",
    "Weak password" : "муу нууц үг",
    "So-so password" : "ердийн нууц үг",
    "Good password" : "зөв нууц үг ",
    "Strong password" : "баттай нууц үг",
    "Groups" : "Бүлгүүд",
    "{actor} changed your password" : "{actor} таны нууц үгийг солив",
    "You changed your password" : "Та өөрийн нууц үг солив",
    "Your password was reset by an administrator" : "Зохицуулагч таны нууц үгийг солив",
    "{actor} changed your email address" : "{actor} таны цахим шуудангийн хаягийг солив",
    "You changed your email address" : "Та өөрийн цахим шуудангийн хаягийг солив",
    "Your email address was changed by an administrator" : "Зохицуулагч таны цахим шуудангийн хаягийг солив",
    "Security" : "Хамгаалалт",
    "Wrong password" : "Нууц үг буруу байна",
    "Authentication error" : "Нотолгооны алдаа",
    "Invalid SMTP password." : "SMTP -н нууц үг буруу байна ",
    "Email setting test" : "Цахим шуудангийн тохиргоог шалгах",
    "If you received this email, the email configuration seems to be correct." : "Хэрэв та энэ цахим захидалыг хүлээн авсан бол цахим шуудангийн тохиргоо нь зөв байна.",
    "Email could not be sent. Check your mail server log" : "Цахим захидлыг илгээж чадсангүй. Цахим шуудангийн серверийн лог шалгана уу.",
    "Settings saved" : "Тохиргоо хадгалагдлаа",
    "Unable to change full name" : "Бүтэн нэрийг солих боломжгүй",
    "Unable to change email address" : "Цахим шуудангийн хаягийг солих боломжгүй",
    "If you did not request this, please contact an administrator." : "Хэрэв та энэ хүсэлтийг илгээгээгүй бол зохицуулагч руу хандана уу.",
    "Set your password" : "Нууц үгээ тохируулна уу",
    "Apps" : "Аппликэйшинууд",
    "Settings" : "Тохиргоо",
    "Personal" : "Хувийн",
    "Sharing" : "Түгээх",
    "Personal info" : "Хувийн мэдээлэл",
    "Create" : "Үүсгэх",
    "Delete" : "Устгах",
    "Save changes" : "Өөрчлөлтийг хадгалах",
    "All" : "бүх",
    "No results" : "Үр дүн байхгүй",
    "Update to {version}" : "{version} хувилбар руу шинэчлэх",
    "Remove" : "Устгах",
    "Visit website" : "Цахим хуудсаар зочлох",
    "User documentation" : "Хэрэглэгчийн баримт бичиг",
    "Admin documentation" : "Админы баримт бичиг",
    "Featured" : "Алдартай",
    "Rename" : "Нэрлэнэ үү",
    "Device" : "Төхөөрөмж",
    "Last activity" : "Хамгийн сүүлийн үйлдэл",
    "App name" : "Аппликэйшны нэр",
    "Username" : "Хэрэглэгчийн нэр",
    "Password" : "Нууц үг",
    "Done" : "Дууссан",
    "Copied!" : "Хуулсан!",
    "Copy" : "Хуулах",
    "Cancel" : "Цуцлах",
    "Display name" : "Харагдах нэр",
    "Email" : "Цахим шуудан",
    "Quota" : " хувь хэмжээ",
    "Language" : "Хэл",
    "Last login" : "Сүүлд нэвтэрсэн огноо",
    "All languages" : "Бүх хэлүүд",
    "Add" : "нэмэх",
    "Unnamed device" : "нэргүй төхөөрөммж",
    "Your apps" : "Таны аппликэйшнүүд",
    "Disabled apps" : "Идэвхижээгүй аппликэйшнүүд",
    "App bundles" : "Аппликэйшны багц",
    "Details" : "Дэлгэрэнгүй",
    "Add group" : "Бүлэг нэмэх",
    "Everyone" : "Бүх хэрэглэгчид",
    "Admins" : "Админууд",
    "Send email to new user" : "Шинэ хэрэглэгч рүү цахим шуудан илгээх",
    "Never" : "хэзээч",
    "Administrator documentation" : "Админы баримт бичиг",
    "Forum" : "Хэлэлцүүлэг",
    "None" : "юу ч үгүй",
    "Login" : "Нэвтрэх",
    "Open documentation" : "бичиг баримт нээх",
    "Server address" : "хүлээн авагчийн хаяг",
    "Port" : "порт",
    "Credentials" : "Итгэмжлэл",
    "SMTP Password" : "Энгийн мэйл дамжуулах протокол-ийн нууц үг",
    "Save" : "Хадгалах",
    "Version" : "Хувилбар",
    "days" : "өдрийн дараа",
    "Always ask for a password" : "Үргэлж нууц үг асуух",
    "Enforce password protection" : "Нууц үгийн хамгаалалтыг хэрэгжүүлэх",
    "Profile picture" : "Профайл зураг",
    "Upload new" : "Шинийг байршуулах",
    "Select from Files" : "Файлуудаас сонгох",
    "Remove image" : "Зургийг хасах",
    "Choose as profile picture" : "Профайл зургаа сонгоно уу",
    "Full name" : "Бүтэн нэр",
    "Phone number" : "Утасны дугаар",
    "Your phone number" : "Таны утасны дугаар",
    "Address" : "Хаяг",
    "Your postal address" : "Таны шуудангийн хаяг",
    "Website" : "Цахим хуудас",
    "Twitter" : "Твиттер",
    "Current password" : "Одоогийн нууц үг",
    "New password" : "Шинэ нууц үг",
    "Change password" : "Нууц үг солих",
    "Contacts" : "Харилцагчид",
    "Public" : "Нийтийн",
    "Close" : "Хаах",
    "mail" : "и-мэйл",
    "Expire after " : " Дуусах хугацаа"
},
"nplurals=2; plural=(n != 1);");
